
#include "cmpinclude.h"
#include "pcl_generic_functions.h"
void init_pcl_generic_functions(){do_init(VV);}
/*	function definition for (DEFGENERIC CLASS-EQ-SPECIALIZER-P)5896	*/

static void L1()
{register object *base=vs_base;
	register object *sup=base+VM1; VC1
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[0];
	base[1]= VV[1];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC CLASSP)5896	*/

static void L2()
{register object *base=vs_base;
	register object *sup=base+VM2; VC2
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[2];
	base[1]= VV[3];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC EQL-SPECIALIZER-P)5896	*/

static void L3()
{register object *base=vs_base;
	register object *sup=base+VM3; VC3
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[4];
	base[1]= VV[5];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC EXACT-CLASS-SPECIALIZER-P)5896	*/

static void L4()
{register object *base=vs_base;
	register object *sup=base+VM4; VC4
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[6];
	base[1]= VV[7];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC FORWARD-REFERENCED-CLASS-P)5896	*/

static void L5()
{register object *base=vs_base;
	register object *sup=base+VM5; VC5
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[8];
	base[1]= VV[9];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC FUNCALLABLE-STANDARD-CLASS-P)5896	*/

static void L6()
{register object *base=vs_base;
	register object *sup=base+VM6; VC6
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[10];
	base[1]= VV[11];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC GENERIC-FUNCTION-P)5896	*/

static void L7()
{register object *base=vs_base;
	register object *sup=base+VM7; VC7
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[12];
	base[1]= VV[13];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC LEGAL-LAMBDA-LIST-P)5896	*/

static void L8()
{register object *base=vs_base;
	register object *sup=base+VM8; VC8
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[14];
	base[1]= VV[15];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC METHOD-COMBINATION-P)5896	*/

static void L9()
{register object *base=vs_base;
	register object *sup=base+VM9; VC9
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[16];
	base[1]= VV[17];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC METHOD-P)5896	*/

static void L10()
{register object *base=vs_base;
	register object *sup=base+VM10; VC10
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[18];
	base[1]= VV[19];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SHORT-METHOD-COMBINATION-P)5896	*/

static void L11()
{register object *base=vs_base;
	register object *sup=base+VM11; VC11
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[20];
	base[1]= VV[21];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-CLASS-P)5896	*/

static void L12()
{register object *base=vs_base;
	register object *sup=base+VM12; VC12
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[22];
	base[1]= VV[23];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SPECIALIZERP)5896	*/

static void L13()
{register object *base=vs_base;
	register object *sup=base+VM13; VC13
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[24];
	base[1]= VV[25];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC STANDARD-ACCESSOR-METHOD-P)5896	*/

static void L14()
{register object *base=vs_base;
	register object *sup=base+VM14; VC14
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[26];
	base[1]= VV[27];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC STANDARD-BOUNDP-METHOD-P)5896	*/

static void L15()
{register object *base=vs_base;
	register object *sup=base+VM15; VC15
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[28];
	base[1]= VV[29];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC STANDARD-CLASS-P)5896	*/

static void L16()
{register object *base=vs_base;
	register object *sup=base+VM16; VC16
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[30];
	base[1]= VV[31];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC STANDARD-GENERIC-FUNCTION-P)5896	*/

static void L17()
{register object *base=vs_base;
	register object *sup=base+VM17; VC17
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[32];
	base[1]= VV[33];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC STANDARD-METHOD-P)5896	*/

static void L18()
{register object *base=vs_base;
	register object *sup=base+VM18; VC18
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[34];
	base[1]= VV[35];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC STANDARD-READER-METHOD-P)5896	*/

static void L19()
{register object *base=vs_base;
	register object *sup=base+VM19; VC19
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[36];
	base[1]= VV[37];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC STANDARD-WRITER-METHOD-P)5896	*/

static void L20()
{register object *base=vs_base;
	register object *sup=base+VM20; VC20
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[38];
	base[1]= VV[39];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC STRUCTURE-CLASS-P)5896	*/

static void L21()
{register object *base=vs_base;
	register object *sup=base+VM21; VC21
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[40];
	base[1]= VV[41];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC ACCESSOR-METHOD-SLOT-DEFINITION)5896	*/

static void L22()
{register object *base=vs_base;
	register object *sup=base+VM22; VC22
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[42];
	base[1]= VV[43];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC CLASS-CAN-PRECEDE-LIST)5896	*/

static void L23()
{register object *base=vs_base;
	register object *sup=base+VM23; VC23
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[44];
	base[1]= VV[45];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC CLASS-DEFSTRUCT-CONSTRUCTOR)5896	*/

static void L24()
{register object *base=vs_base;
	register object *sup=base+VM24; VC24
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[46];
	base[1]= VV[47];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC CLASS-DEFSTRUCT-FORM)5896	*/

static void L25()
{register object *base=vs_base;
	register object *sup=base+VM25; VC25
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[48];
	base[1]= VV[49];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC CLASS-DIRECT-SUBCLASSES)5896	*/

static void L26()
{register object *base=vs_base;
	register object *sup=base+VM26; VC26
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[50];
	base[1]= VV[51];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC CLASS-DIRECT-SUPERCLASSES)5896	*/

static void L27()
{register object *base=vs_base;
	register object *sup=base+VM27; VC27
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[52];
	base[1]= VV[53];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC CLASS-EQ-SPECIALIZER)5896	*/

static void L28()
{register object *base=vs_base;
	register object *sup=base+VM28; VC28
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[54];
	base[1]= VV[55];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC CLASS-INCOMPATIBLE-SUPERCLASS-LIST)5896	*/

static void L29()
{register object *base=vs_base;
	register object *sup=base+VM29; VC29
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[56];
	base[1]= VV[57];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC CLASS-INITIALIZE-INFO)5896	*/

static void L30()
{register object *base=vs_base;
	register object *sup=base+VM30; VC30
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[58];
	base[1]= VV[59];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC CLASS-NAME)5896	*/

static void L31()
{register object *base=vs_base;
	register object *sup=base+VM31; VC31
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[60];
	base[1]= VV[61];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC CLASS-PRECEDENCE-LIST)5896	*/

static void L32()
{register object *base=vs_base;
	register object *sup=base+VM32; VC32
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[62];
	base[1]= VV[63];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC CLASS-PREDICATE-NAME)5896	*/

static void L33()
{register object *base=vs_base;
	register object *sup=base+VM33; VC33
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[64];
	base[1]= VV[65];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC CLASS-WRAPPER)5896	*/

static void L34()
{register object *base=vs_base;
	register object *sup=base+VM34; VC34
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[66];
	base[1]= VV[67];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC DEFINITION-SOURCE)5896	*/

static void L35()
{register object *base=vs_base;
	register object *sup=base+VM35; VC35
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[68];
	base[1]= VV[69];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC EQL-SPECIALIZER-OBJECT)5896	*/

static void L36()
{register object *base=vs_base;
	register object *sup=base+VM36; VC36
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[70];
	base[1]= VV[71];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC GENERIC-FUNCTION-METHOD-CLASS)5896	*/

static void L37()
{register object *base=vs_base;
	register object *sup=base+VM37; VC37
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[72];
	base[1]= VV[73];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC GENERIC-FUNCTION-METHOD-COMBINATION)5896	*/

static void L38()
{register object *base=vs_base;
	register object *sup=base+VM38; VC38
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[74];
	base[1]= VV[75];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC GENERIC-FUNCTION-METHODS)5896	*/

static void L39()
{register object *base=vs_base;
	register object *sup=base+VM39; VC39
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[76];
	base[1]= VV[77];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC GENERIC-FUNCTION-NAME)5896	*/

static void L40()
{register object *base=vs_base;
	register object *sup=base+VM40; VC40
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[78];
	base[1]= VV[79];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC GF-ARG-INFO)5896	*/

static void L41()
{register object *base=vs_base;
	register object *sup=base+VM41; VC41
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[80];
	base[1]= VV[81];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC GF-DFUN-STATE)5896	*/

static void L42()
{register object *base=vs_base;
	register object *sup=base+VM42; VC42
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[82];
	base[1]= VV[83];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC GF-PRETTY-ARGLIST)5896	*/

static void L43()
{register object *base=vs_base;
	register object *sup=base+VM43; VC43
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[84];
	base[1]= VV[85];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC LONG-METHOD-COMBINATION-FUNCTION)5896	*/

static void L44()
{register object *base=vs_base;
	register object *sup=base+VM44; VC44
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[86];
	base[1]= VV[87];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC METHOD-COMBINATION-DOCUMENTATION)5896	*/

static void L45()
{register object *base=vs_base;
	register object *sup=base+VM45; VC45
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[88];
	base[1]= VV[89];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC METHOD-COMBINATION-OPTIONS)5896	*/

static void L46()
{register object *base=vs_base;
	register object *sup=base+VM46; VC46
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[90];
	base[1]= VV[91];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC METHOD-COMBINATION-TYPE)5896	*/

static void L47()
{register object *base=vs_base;
	register object *sup=base+VM47; VC47
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[92];
	base[1]= VV[93];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC METHOD-FAST-FUNCTION)5896	*/

static void L48()
{register object *base=vs_base;
	register object *sup=base+VM48; VC48
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[94];
	base[1]= VV[95];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC METHOD-GENERIC-FUNCTION)5896	*/

static void L49()
{register object *base=vs_base;
	register object *sup=base+VM49; VC49
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[96];
	base[1]= VV[97];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC OBJECT-PLIST)5896	*/

static void L50()
{register object *base=vs_base;
	register object *sup=base+VM50; VC50
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[98];
	base[1]= VV[99];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SHORT-COMBINATION-IDENTITY-WITH-ONE-ARGUMENT)5896	*/

static void L51()
{register object *base=vs_base;
	register object *sup=base+VM51; VC51
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[100];
	base[1]= VV[101];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SHORT-COMBINATION-OPERATOR)5896	*/

static void L52()
{register object *base=vs_base;
	register object *sup=base+VM52; VC52
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[102];
	base[1]= VV[103];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-DEFINITION-BOUNDP-FUNCTION)5896	*/

static void L53()
{register object *base=vs_base;
	register object *sup=base+VM53; VC53
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[104];
	base[1]= VV[105];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-DEFINITION-CLASS)5896	*/

static void L54()
{register object *base=vs_base;
	register object *sup=base+VM54; VC54
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[106];
	base[1]= VV[107];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-DEFINITION-DEFSTRUCT-ACCESSOR-SYMBOL)5896	*/

static void L55()
{register object *base=vs_base;
	register object *sup=base+VM55; VC55
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[108];
	base[1]= VV[109];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-DEFINITION-INITARGS)5896	*/

static void L56()
{register object *base=vs_base;
	register object *sup=base+VM56; VC56
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[110];
	base[1]= VV[111];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-DEFINITION-INITFORM)5896	*/

static void L57()
{register object *base=vs_base;
	register object *sup=base+VM57; VC57
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[112];
	base[1]= VV[113];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-DEFINITION-INITFUNCTION)5896	*/

static void L58()
{register object *base=vs_base;
	register object *sup=base+VM58; VC58
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[114];
	base[1]= VV[115];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-DEFINITION-INTERNAL-READER-FUNCTION)5896	*/

static void L59()
{register object *base=vs_base;
	register object *sup=base+VM59; VC59
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[116];
	base[1]= VV[117];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-DEFINITION-INTERNAL-WRITER-FUNCTION)5896	*/

static void L60()
{register object *base=vs_base;
	register object *sup=base+VM60; VC60
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[118];
	base[1]= VV[119];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-DEFINITION-LOCATION)5896	*/

static void L61()
{register object *base=vs_base;
	register object *sup=base+VM61; VC61
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[120];
	base[1]= VV[121];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-DEFINITION-NAME)5896	*/

static void L62()
{register object *base=vs_base;
	register object *sup=base+VM62; VC62
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[122];
	base[1]= VV[123];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-DEFINITION-READER-FUNCTION)5896	*/

static void L63()
{register object *base=vs_base;
	register object *sup=base+VM63; VC63
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[124];
	base[1]= VV[125];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-DEFINITION-READERS)5896	*/

static void L64()
{register object *base=vs_base;
	register object *sup=base+VM64; VC64
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[126];
	base[1]= VV[127];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-DEFINITION-TYPE)5896	*/

static void L65()
{register object *base=vs_base;
	register object *sup=base+VM65; VC65
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[128];
	base[1]= VV[129];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-DEFINITION-WRITER-FUNCTION)5896	*/

static void L66()
{register object *base=vs_base;
	register object *sup=base+VM66; VC66
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[130];
	base[1]= VV[131];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-DEFINITION-WRITERS)5896	*/

static void L67()
{register object *base=vs_base;
	register object *sup=base+VM67; VC67
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[132];
	base[1]= VV[133];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SPECIALIZER-OBJECT)5896	*/

static void L68()
{register object *base=vs_base;
	register object *sup=base+VM68; VC68
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[134];
	base[1]= VV[135];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SPECIALIZER-TYPE)5896	*/

static void L69()
{register object *base=vs_base;
	register object *sup=base+VM69; VC69
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[136];
	base[1]= VV[137];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF CLASS-DEFSTRUCT-CONSTRUCTOR))5896	*/

static void L70()
{register object *base=vs_base;
	register object *sup=base+VM70; VC70
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[138];
	base[1]= VV[139];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF CLASS-DEFSTRUCT-FORM))5896	*/

static void L71()
{register object *base=vs_base;
	register object *sup=base+VM71; VC71
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[140];
	base[1]= VV[141];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF CLASS-DIRECT-SLOTS))5896	*/

static void L72()
{register object *base=vs_base;
	register object *sup=base+VM72; VC72
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[142];
	base[1]= VV[143];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF CLASS-INCOMPATIBLE-SUPERCLASS-LIST))5896	*/

static void L73()
{register object *base=vs_base;
	register object *sup=base+VM73; VC73
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[144];
	base[1]= VV[145];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF CLASS-INITIALIZE-INFO))5896	*/

static void L74()
{register object *base=vs_base;
	register object *sup=base+VM74; VC74
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[146];
	base[1]= VV[147];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF CLASS-NAME))5896	*/

static void L75()
{register object *base=vs_base;
	register object *sup=base+VM75; VC75
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[148];
	base[1]= VV[149];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF CLASS-SLOTS))5896	*/

static void L76()
{register object *base=vs_base;
	register object *sup=base+VM76; VC76
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[150];
	base[1]= VV[151];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF GENERIC-FUNCTION-METHOD-CLASS))5896	*/

static void L77()
{register object *base=vs_base;
	register object *sup=base+VM77; VC77
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[152];
	base[1]= VV[153];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF GENERIC-FUNCTION-METHOD-COMBINATION))5896	*/

static void L78()
{register object *base=vs_base;
	register object *sup=base+VM78; VC78
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[154];
	base[1]= VV[155];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF GENERIC-FUNCTION-METHODS))5896	*/

static void L79()
{register object *base=vs_base;
	register object *sup=base+VM79; VC79
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[156];
	base[1]= VV[157];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF GENERIC-FUNCTION-NAME))5896	*/

static void L80()
{register object *base=vs_base;
	register object *sup=base+VM80; VC80
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[158];
	base[1]= VV[159];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF GF-DFUN-STATE))5896	*/

static void L81()
{register object *base=vs_base;
	register object *sup=base+VM81; VC81
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[160];
	base[1]= VV[161];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF GF-PRETTY-ARGLIST))5896	*/

static void L82()
{register object *base=vs_base;
	register object *sup=base+VM82; VC82
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[162];
	base[1]= VV[163];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF METHOD-GENERIC-FUNCTION))5896	*/

static void L83()
{register object *base=vs_base;
	register object *sup=base+VM83; VC83
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[164];
	base[1]= VV[165];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF OBJECT-PLIST))5896	*/

static void L84()
{register object *base=vs_base;
	register object *sup=base+VM84; VC84
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[166];
	base[1]= VV[167];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF SLOT-DEFINITION-ALLOCATION))5896	*/

static void L85()
{register object *base=vs_base;
	register object *sup=base+VM85; VC85
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[168];
	base[1]= VV[169];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF SLOT-DEFINITION-BOUNDP-FUNCTION))5896	*/

static void L86()
{register object *base=vs_base;
	register object *sup=base+VM86; VC86
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[170];
	base[1]= VV[171];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF SLOT-DEFINITION-CLASS))5896	*/

static void L87()
{register object *base=vs_base;
	register object *sup=base+VM87; VC87
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[172];
	base[1]= VV[173];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF SLOT-DEFINITION-DEFSTRUCT-ACCESSOR-SYMBOL))5896	*/

static void L88()
{register object *base=vs_base;
	register object *sup=base+VM88; VC88
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[174];
	base[1]= VV[175];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF SLOT-DEFINITION-INITARGS))5896	*/

static void L89()
{register object *base=vs_base;
	register object *sup=base+VM89; VC89
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[176];
	base[1]= VV[177];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF SLOT-DEFINITION-INITFORM))5896	*/

static void L90()
{register object *base=vs_base;
	register object *sup=base+VM90; VC90
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[178];
	base[1]= VV[179];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF SLOT-DEFINITION-INITFUNCTION))5896	*/

static void L91()
{register object *base=vs_base;
	register object *sup=base+VM91; VC91
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[180];
	base[1]= VV[181];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF SLOT-DEFINITION-INTERNAL-READER-FUNCTION))5896	*/

static void L92()
{register object *base=vs_base;
	register object *sup=base+VM92; VC92
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[182];
	base[1]= VV[183];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF SLOT-DEFINITION-INTERNAL-WRITER-FUNCTION))5896	*/

static void L93()
{register object *base=vs_base;
	register object *sup=base+VM93; VC93
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[184];
	base[1]= VV[185];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF SLOT-DEFINITION-LOCATION))5896	*/

static void L94()
{register object *base=vs_base;
	register object *sup=base+VM94; VC94
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[186];
	base[1]= VV[187];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF SLOT-DEFINITION-NAME))5896	*/

static void L95()
{register object *base=vs_base;
	register object *sup=base+VM95; VC95
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[188];
	base[1]= VV[189];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF SLOT-DEFINITION-READER-FUNCTION))5896	*/

static void L96()
{register object *base=vs_base;
	register object *sup=base+VM96; VC96
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[190];
	base[1]= VV[191];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF SLOT-DEFINITION-READERS))5896	*/

static void L97()
{register object *base=vs_base;
	register object *sup=base+VM97; VC97
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[192];
	base[1]= VV[193];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF SLOT-DEFINITION-TYPE))5896	*/

static void L98()
{register object *base=vs_base;
	register object *sup=base+VM98; VC98
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[194];
	base[1]= VV[195];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF SLOT-DEFINITION-WRITER-FUNCTION))5896	*/

static void L99()
{register object *base=vs_base;
	register object *sup=base+VM99; VC99
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[196];
	base[1]= VV[197];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF SLOT-DEFINITION-WRITERS))5896	*/

static void L100()
{register object *base=vs_base;
	register object *sup=base+VM100; VC100
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[198];
	base[1]= VV[199];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC ACCESSOR-METHOD-CLASS)5896	*/

static void L101()
{register object *base=vs_base;
	register object *sup=base+VM101; VC101
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[200];
	base[1]= VV[201];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC ACCESSOR-METHOD-SLOT-NAME)5896	*/

static void L102()
{register object *base=vs_base;
	register object *sup=base+VM102; VC102
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[202];
	base[1]= VV[203];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC CLASS-CONSTRUCTORS)5896	*/

static void L103()
{register object *base=vs_base;
	register object *sup=base+VM103; VC103
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[204];
	base[1]= VV[205];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC CLASS-DEFAULT-INITARGS)5896	*/

static void L104()
{register object *base=vs_base;
	register object *sup=base+VM104; VC104
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[206];
	base[1]= VV[207];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC CLASS-DIRECT-DEFAULT-INITARGS)5896	*/

static void L105()
{register object *base=vs_base;
	register object *sup=base+VM105; VC105
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[208];
	base[1]= VV[209];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC CLASS-DIRECT-SLOTS)5896	*/

static void L106()
{register object *base=vs_base;
	register object *sup=base+VM106; VC106
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[210];
	base[1]= VV[211];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC CLASS-FINALIZED-P)5896	*/

static void L107()
{register object *base=vs_base;
	register object *sup=base+VM107; VC107
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[212];
	base[1]= VV[213];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC CLASS-PROTOTYPE)5896	*/

static void L108()
{register object *base=vs_base;
	register object *sup=base+VM108; VC108
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[214];
	base[1]= VV[215];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC CLASS-SLOT-CELLS)5896	*/

static void L109()
{register object *base=vs_base;
	register object *sup=base+VM109; VC109
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[216];
	base[1]= VV[217];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC CLASS-SLOTS)5896	*/

static void L110()
{register object *base=vs_base;
	register object *sup=base+VM110; VC110
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[218];
	base[1]= VV[219];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC COMPUTE-CLASS-PRECEDENCE-LIST)5896	*/

static void L111()
{register object *base=vs_base;
	register object *sup=base+VM111; VC111
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[220];
	base[1]= VV[221];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC COMPUTE-DEFAULT-INITARGS)5896	*/

static void L112()
{register object *base=vs_base;
	register object *sup=base+VM112; VC112
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[222];
	base[1]= VV[223];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC COMPUTE-DISCRIMINATING-FUNCTION)5896	*/

static void L113()
{register object *base=vs_base;
	register object *sup=base+VM113; VC113
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[224];
	base[1]= VV[225];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC COMPUTE-DISCRIMINATING-FUNCTION-ARGLIST-INFO)5896	*/

static void L114()
{register object *base=vs_base;
	register object *sup=base+VM114; VC114
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[226];
	base[1]= VV[227];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC COMPUTE-SLOTS)5896	*/

static void L115()
{register object *base=vs_base;
	register object *sup=base+VM115; VC115
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[228];
	base[1]= VV[229];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC FINALIZE-INHERITANCE)5896	*/

static void L116()
{register object *base=vs_base;
	register object *sup=base+VM116; VC116
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[230];
	base[1]= VV[231];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC FUNCTION-KEYWORDS)5896	*/

static void L117()
{register object *base=vs_base;
	register object *sup=base+VM117; VC117
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[232];
	base[1]= VV[233];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC GENERIC-FUNCTION-LAMBDA-LIST)5896	*/

static void L118()
{register object *base=vs_base;
	register object *sup=base+VM118; VC118
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[234];
	base[1]= VV[235];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC GENERIC-FUNCTION-PRETTY-ARGLIST)5896	*/

static void L119()
{register object *base=vs_base;
	register object *sup=base+VM119; VC119
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[236];
	base[1]= VV[237];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC GF-FAST-METHOD-FUNCTION-P)5896	*/

static void L120()
{register object *base=vs_base;
	register object *sup=base+VM120; VC120
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[238];
	base[1]= VV[239];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC INITIALIZE-INTERNAL-SLOT-FUNCTIONS)5896	*/

static void L121()
{register object *base=vs_base;
	register object *sup=base+VM121; VC121
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[240];
	base[1]= VV[241];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC MAKE-INSTANCES-OBSOLETE)5896	*/

static void L122()
{register object *base=vs_base;
	register object *sup=base+VM122; VC122
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[242];
	base[1]= VV[243];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC METHOD-FUNCTION)5896	*/

static void L123()
{register object *base=vs_base;
	register object *sup=base+VM123; VC123
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[244];
	base[1]= VV[245];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC METHOD-LAMBDA-LIST)5896	*/

static void L124()
{register object *base=vs_base;
	register object *sup=base+VM124; VC124
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[246];
	base[1]= VV[247];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC METHOD-PRETTY-ARGLIST)5896	*/

static void L125()
{register object *base=vs_base;
	register object *sup=base+VM125; VC125
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[248];
	base[1]= VV[249];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC METHOD-QUALIFIERS)5896	*/

static void L126()
{register object *base=vs_base;
	register object *sup=base+VM126; VC126
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[250];
	base[1]= VV[251];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC METHOD-SPECIALIZERS)5896	*/

static void L127()
{register object *base=vs_base;
	register object *sup=base+VM127; VC127
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[252];
	base[1]= VV[253];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC RAW-INSTANCE-ALLOCATOR)5896	*/

static void L128()
{register object *base=vs_base;
	register object *sup=base+VM128; VC128
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[254];
	base[1]= VV[255];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-DEFINITION-ALLOCATION)5896	*/

static void L129()
{register object *base=vs_base;
	register object *sup=base+VM129; VC129
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[256];
	base[1]= VV[257];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOTS-FETCHER)5896	*/

static void L130()
{register object *base=vs_base;
	register object *sup=base+VM130; VC130
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[258];
	base[1]= VV[259];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SPECIALIZER-CLASS)5896	*/

static void L131()
{register object *base=vs_base;
	register object *sup=base+VM131; VC131
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[260];
	base[1]= VV[261];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SPECIALIZER-DIRECT-GENERIC-FUNCTIONS)5896	*/

static void L132()
{register object *base=vs_base;
	register object *sup=base+VM132; VC132
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[262];
	base[1]= VV[263];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SPECIALIZER-DIRECT-METHODS)5896	*/

static void L133()
{register object *base=vs_base;
	register object *sup=base+VM133; VC133
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[264];
	base[1]= VV[265];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SPECIALIZER-METHOD-TABLE)5896	*/

static void L134()
{register object *base=vs_base;
	register object *sup=base+VM134; VC134
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[266];
	base[1]= VV[267];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC UPDATE-CONSTRUCTORS)5896	*/

static void L135()
{register object *base=vs_base;
	register object *sup=base+VM135; VC135
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[268];
	base[1]= VV[269];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC WRAPPER-FETCHER)5896	*/

static void L136()
{register object *base=vs_base;
	register object *sup=base+VM136; VC136
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[270];
	base[1]= VV[271];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC ADD-DEPENDENT)5896	*/

static void L137()
{register object *base=vs_base;
	register object *sup=base+VM137; VC137
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[272];
	base[1]= VV[273];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC ADD-DIRECT-METHOD)5896	*/

static void L138()
{register object *base=vs_base;
	register object *sup=base+VM138; VC138
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[274];
	base[1]= VV[275];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC ADD-DIRECT-SUBCLASS)5896	*/

static void L139()
{register object *base=vs_base;
	register object *sup=base+VM139; VC139
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[276];
	base[1]= VV[277];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC ADD-METHOD)5896	*/

static void L140()
{register object *base=vs_base;
	register object *sup=base+VM140; VC140
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[278];
	base[1]= VV[279];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC CHANGE-CLASS)5896	*/

static void L141()
{register object *base=vs_base;
	register object *sup=base+VM141; VC141
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[280];
	base[1]= VV[281];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC CLASS-SLOT-VALUE)5896	*/

static void L142()
{register object *base=vs_base;
	register object *sup=base+VM142; VC142
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[282];
	base[1]= VV[283];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC COMPATIBLE-META-CLASS-CHANGE-P)5896	*/

static void L143()
{register object *base=vs_base;
	register object *sup=base+VM143; VC143
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[284];
	base[1]= VV[285];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC COMPUTE-APPLICABLE-METHODS)5896	*/

static void L144()
{register object *base=vs_base;
	register object *sup=base+VM144; VC144
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[286];
	base[1]= VV[287];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC COMPUTE-APPLICABLE-METHODS-USING-CLASSES)5896	*/

static void L145()
{register object *base=vs_base;
	register object *sup=base+VM145; VC145
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[288];
	base[1]= VV[289];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC COMPUTE-EFFECTIVE-SLOT-DEFINITION)5896	*/

static void L146()
{register object *base=vs_base;
	register object *sup=base+VM146; VC146
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[290];
	base[1]= VV[291];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC COMPUTE-EFFECTIVE-SLOT-DEFINITION-INITARGS)5896	*/

static void L147()
{register object *base=vs_base;
	register object *sup=base+VM147; VC147
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[292];
	base[1]= VV[293];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC DEFAULT-INITARGS)5896	*/

static void L148()
{register object *base=vs_base;
	register object *sup=base+VM148; VC148
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[294];
	base[1]= VV[295];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC DESCRIBE-OBJECT)5896	*/

static void L149()
{register object *base=vs_base;
	register object *sup=base+VM149; VC149
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[296];
	base[1]= VV[297];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC DIRECT-SLOT-DEFINITION-CLASS)5896	*/

static void L150()
{register object *base=vs_base;
	register object *sup=base+VM150; VC150
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[298];
	base[1]= VV[299];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC EFFECTIVE-SLOT-DEFINITION-CLASS)5896	*/

static void L151()
{register object *base=vs_base;
	register object *sup=base+VM151; VC151
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[300];
	base[1]= VV[301];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC INFORM-TYPE-SYSTEM-ABOUT-CLASS)5896	*/

static void L152()
{register object *base=vs_base;
	register object *sup=base+VM152; VC152
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[302];
	base[1]= VV[303];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC LEGAL-DOCUMENTATION-P)5896	*/

static void L153()
{register object *base=vs_base;
	register object *sup=base+VM153; VC153
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[304];
	base[1]= VV[305];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC LEGAL-METHOD-FUNCTION-P)5896	*/

static void L154()
{register object *base=vs_base;
	register object *sup=base+VM154; VC154
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[306];
	base[1]= VV[307];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC LEGAL-QUALIFIER-P)5896	*/

static void L155()
{register object *base=vs_base;
	register object *sup=base+VM155; VC155
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[308];
	base[1]= VV[309];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC LEGAL-QUALIFIERS-P)5896	*/

static void L156()
{register object *base=vs_base;
	register object *sup=base+VM156; VC156
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[310];
	base[1]= VV[311];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC LEGAL-SLOT-NAME-P)5896	*/

static void L157()
{register object *base=vs_base;
	register object *sup=base+VM157; VC157
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[312];
	base[1]= VV[313];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC LEGAL-SPECIALIZER-P)5896	*/

static void L158()
{register object *base=vs_base;
	register object *sup=base+VM158; VC158
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[314];
	base[1]= VV[315];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC LEGAL-SPECIALIZERS-P)5896	*/

static void L159()
{register object *base=vs_base;
	register object *sup=base+VM159; VC159
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[316];
	base[1]= VV[317];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC MAKE-BOUNDP-METHOD-FUNCTION)5896	*/

static void L160()
{register object *base=vs_base;
	register object *sup=base+VM160; VC160
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[318];
	base[1]= VV[319];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC MAKE-READER-METHOD-FUNCTION)5896	*/

static void L161()
{register object *base=vs_base;
	register object *sup=base+VM161; VC161
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[320];
	base[1]= VV[321];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC MAKE-WRITER-METHOD-FUNCTION)5896	*/

static void L162()
{register object *base=vs_base;
	register object *sup=base+VM162; VC162
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[322];
	base[1]= VV[323];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC MAP-DEPENDENTS)5896	*/

static void L163()
{register object *base=vs_base;
	register object *sup=base+VM163; VC163
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[324];
	base[1]= VV[325];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC PRINT-OBJECT)5896	*/

static void L164()
{register object *base=vs_base;
	register object *sup=base+VM164; VC164
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[326];
	base[1]= VV[327];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC REMOVE-BOUNDP-METHOD)5896	*/

static void L165()
{register object *base=vs_base;
	register object *sup=base+VM165; VC165
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[328];
	base[1]= VV[329];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC REMOVE-DEPENDENT)5896	*/

static void L166()
{register object *base=vs_base;
	register object *sup=base+VM166; VC166
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[330];
	base[1]= VV[331];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC REMOVE-DIRECT-METHOD)5896	*/

static void L167()
{register object *base=vs_base;
	register object *sup=base+VM167; VC167
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[332];
	base[1]= VV[333];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC REMOVE-DIRECT-SUBCLASS)5896	*/

static void L168()
{register object *base=vs_base;
	register object *sup=base+VM168; VC168
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[334];
	base[1]= VV[335];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC REMOVE-METHOD)5896	*/

static void L169()
{register object *base=vs_base;
	register object *sup=base+VM169; VC169
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[336];
	base[1]= VV[337];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC REMOVE-READER-METHOD)5896	*/

static void L170()
{register object *base=vs_base;
	register object *sup=base+VM170; VC170
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[338];
	base[1]= VV[339];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC REMOVE-WRITER-METHOD)5896	*/

static void L171()
{register object *base=vs_base;
	register object *sup=base+VM171; VC171
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[340];
	base[1]= VV[341];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SAME-SPECIALIZER-P)5896	*/

static void L172()
{register object *base=vs_base;
	register object *sup=base+VM172; VC172
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[342];
	base[1]= VV[343];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-ACCESSOR-FUNCTION)5896	*/

static void L173()
{register object *base=vs_base;
	register object *sup=base+VM173; VC173
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[344];
	base[1]= VV[345];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-ACCESSOR-STD-P)5896	*/

static void L174()
{register object *base=vs_base;
	register object *sup=base+VM174; VC174
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[346];
	base[1]= VV[347];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOTS-TO-INSPECT)5896	*/

static void L175()
{register object *base=vs_base;
	register object *sup=base+VM175; VC175
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[348];
	base[1]= VV[349];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC UPDATE-GF-DFUN)5896	*/

static void L176()
{register object *base=vs_base;
	register object *sup=base+VM176; VC176
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[350];
	base[1]= VV[351];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC VALIDATE-SUPERCLASS)5896	*/

static void L177()
{register object *base=vs_base;
	register object *sup=base+VM177; VC177
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[352];
	base[1]= VV[353];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC ADD-BOUNDP-METHOD)5896	*/

static void L178()
{register object *base=vs_base;
	register object *sup=base+VM178; VC178
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[354];
	base[1]= VV[355];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC ADD-READER-METHOD)5896	*/

static void L179()
{register object *base=vs_base;
	register object *sup=base+VM179; VC179
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[356];
	base[1]= VV[357];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC ADD-WRITER-METHOD)5896	*/

static void L180()
{register object *base=vs_base;
	register object *sup=base+VM180; VC180
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[358];
	base[1]= VV[359];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF CLASS-SLOT-VALUE))5897	*/

static void L181()
{register object *base=vs_base;
	register object *sup=base+VM181; VC181
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[360];
	base[1]= VV[361];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC COMPUTE-EFFECTIVE-METHOD)5897	*/

static void L182()
{register object *base=vs_base;
	register object *sup=base+VM182; VC182
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[362];
	base[1]= VV[363];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC COMPUTE-SLOT-ACCESSOR-INFO)5897	*/

static void L183()
{register object *base=vs_base;
	register object *sup=base+VM183; VC183
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[364];
	base[1]= VV[365];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC FIND-METHOD-COMBINATION)5897	*/

static void L184()
{register object *base=vs_base;
	register object *sup=base+VM184; VC184
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[366];
	base[1]= VV[367];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF SLOT-ACCESSOR-FUNCTION))5898	*/

static void L185()
{register object *base=vs_base;
	register object *sup=base+VM185; VC185
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[368];
	base[1]= VV[369];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF SLOT-ACCESSOR-STD-P))5899	*/

static void L186()
{register object *base=vs_base;
	register object *sup=base+VM186; VC186
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[370];
	base[1]= VV[371];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-BOUNDP-USING-CLASS)5899	*/

static void L187()
{register object *base=vs_base;
	register object *sup=base+VM187; VC187
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[372];
	base[1]= VV[373];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-MAKUNBOUND-USING-CLASS)5899	*/

static void L188()
{register object *base=vs_base;
	register object *sup=base+VM188; VC188
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[374];
	base[1]= VV[375];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-UNBOUND)5899	*/

static void L189()
{register object *base=vs_base;
	register object *sup=base+VM189; VC189
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[376];
	base[1]= VV[377];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-VALUE-USING-CLASS)5899	*/

static void L190()
{register object *base=vs_base;
	register object *sup=base+VM190; VC190
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[378];
	base[1]= VV[379];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC MAKE-METHOD-LAMBDA)5899	*/

static void L191()
{register object *base=vs_base;
	register object *sup=base+VM191; VC191
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[380];
	base[1]= VV[381];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF SLOT-VALUE-USING-CLASS))5899	*/

static void L192()
{register object *base=vs_base;
	register object *sup=base+VM192; VC192
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[382];
	base[1]= VV[383];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC MAKE-METHOD-INITARGS-FORM)5899	*/

static void L193()
{register object *base=vs_base;
	register object *sup=base+VM193; VC193
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[384];
	base[1]= VV[385];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC (SETF DOCUMENTATION))5900	*/

static void L194()
{register object *base=vs_base;
	register object *sup=base+VM194; VC194
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[386];
	base[1]= VV[387];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC DOCUMENTATION)5900	*/

static void L195()
{register object *base=vs_base;
	register object *sup=base+VM195; VC195
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[388];
	base[1]= VV[389];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC GET-METHOD)5900	*/

static void L196()
{register object *base=vs_base;
	register object *sup=base+VM196; VC196
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[390];
	base[1]= VV[391];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC REMOVE-NAMED-METHOD)5900	*/

static void L197()
{register object *base=vs_base;
	register object *sup=base+VM197; VC197
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[392];
	base[1]= VV[393];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SLOT-MISSING)5900	*/

static void L198()
{register object *base=vs_base;
	register object *sup=base+VM198; VC198
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[394];
	base[1]= VV[395];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC ALLOCATE-INSTANCE)5900	*/

static void L199()
{register object *base=vs_base;
	register object *sup=base+VM199; VC199
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[396];
	base[1]= VV[397];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC ENSURE-CLASS-USING-CLASS)5900	*/

static void L200()
{register object *base=vs_base;
	register object *sup=base+VM200; VC200
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[398];
	base[1]= VV[399];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC ENSURE-GENERIC-FUNCTION-USING-CLASS)5900	*/

static void L201()
{register object *base=vs_base;
	register object *sup=base+VM201; VC201
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[400];
	base[1]= VV[401];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC INITIALIZE-INSTANCE)5900	*/

static void L202()
{register object *base=vs_base;
	register object *sup=base+VM202; VC202
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[402];
	base[1]= VV[403];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC MAKE-INSTANCE)5900	*/

static void L203()
{register object *base=vs_base;
	register object *sup=base+VM203; VC203
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[404];
	base[1]= VV[405];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC NO-APPLICABLE-METHOD)5900	*/

static void L204()
{register object *base=vs_base;
	register object *sup=base+VM204; VC204
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[406];
	base[1]= VV[407];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC READER-METHOD-CLASS)5900	*/

static void L205()
{register object *base=vs_base;
	register object *sup=base+VM205; VC205
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[408];
	base[1]= VV[409];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC REINITIALIZE-INSTANCE)5900	*/

static void L206()
{register object *base=vs_base;
	register object *sup=base+VM206; VC206
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[410];
	base[1]= VV[411];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC SHARED-INITIALIZE)5900	*/

static void L207()
{register object *base=vs_base;
	register object *sup=base+VM207; VC207
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[412];
	base[1]= VV[413];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC UPDATE-DEPENDENT)5900	*/

static void L208()
{register object *base=vs_base;
	register object *sup=base+VM208; VC208
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[414];
	base[1]= VV[415];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC UPDATE-INSTANCE-FOR-DIFFERENT-CLASS)5900	*/

static void L209()
{register object *base=vs_base;
	register object *sup=base+VM209; VC209
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[416];
	base[1]= VV[417];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC UPDATE-INSTANCE-FOR-REDEFINED-CLASS)5900	*/

static void L210()
{register object *base=vs_base;
	register object *sup=base+VM210; VC210
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[418];
	base[1]= VV[419];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
/*	function definition for (DEFGENERIC WRITER-METHOD-CLASS)5900	*/

static void L211()
{register object *base=vs_base;
	register object *sup=base+VM211; VC211
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	base[0]= VV[420];
	base[1]= VV[421];
	vs_top=(vs_base=base+0)+2;
	(void) (*Lnk422)();
	return;
}
static void LnkT422(){ call_or_link(VV[422],(void **)(void *)&Lnk422);} /* LOAD-DEFGENERIC */

#ifdef SYSTEM_SPECIAL_INIT
SYSTEM_SPECIAL_INIT
#endif

